;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "backline" "20251101.1936"
  "Preserve appearance of outline headings."
  '((emacs               "27.1")
    (compat              "30.1")
    (outline-minor-faces "1.2"))
  :url "https://github.com/tarsius/backline"
  :commit "821dab84aba746247be184066b2a69a6545ed346"
  :revdesc "821dab84aba7"
  :keywords '("outlines")
  :authors '(("Jonas Bernoulli" . "emacs.backline@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.backline@jonas.bernoulli.dev")))
